@@ -1,10 +1,7 @@
 from logging import getLogger
 from typing import Optional
 
-from aiogram import Bot, Dispatcher
-from aiogram.types.base import TelegramObject
-
-from state_manager.models.dependencys.base import BaseDependencyStorage, back_to_pre_state_, BaseStateManager
+from state_manager.models.dependencys.base import back_to_pre_state_, BaseStateManager
 from state_manager.models.state import StateData
 from state_manager.types import Context, Data
 
@@ -29,13 +26,3 @@ class AiogramStateManager(BaseStateManager):
 
     class Config:
         arbitrary_types_allowed = True
-
-
-class AiogramDependencyStorage(BaseDependencyStorage):
-    bot: Bot
-    dispatcher: Dispatcher
-    context: TelegramObject
-    data: Optional[dict] = None
-
-    class Config:
-        arbitrary_types_allowed = True
