@@ -1,9 +1,9 @@
 from logging import getLogger
 from typing import Optional
 
-from vkwave.bots.addons.easy.base_easy_bot import SimpleBotEvent, BaseSimpleLongPollBot
+from vkwave.bots.addons.easy.base_easy_bot import SimpleBotEvent
 
-from state_manager.models.dependencys.base import BaseDependencyStorage, BaseStateManager, back_to_pre_state_
+from state_manager.models.dependencys.base import BaseStateManager, back_to_pre_state_
 from state_manager.models.state import StateData
 from state_manager.types import Data
 
@@ -29,11 +29,3 @@ class VkWaveStateManager(BaseStateManager):
 
     class Config:
         arbitrary_types_allowed = True
-
-
-class VkWaveDependencyStorage(BaseDependencyStorage):
-    bot: BaseSimpleLongPollBot
-    context: SimpleBotEvent
-
-    class Config:
-        arbitrary_types_allowed = True
